@@ -3,15 +3,13 @@
 //! # Example
 //!
 //! ```no_run
-//! fn main() {
-//!     cpreprocess::cpreprocess!(r#"
-//!         #define MACRO(NAME) fn print_ ## NAME () { println!("hello world"); }
+//! cpreprocess::cpreprocess!(r#"
+//!     #define MACRO(NAME) fn print_ ## NAME () { println!("hello world"); }
 //!
-//!         MACRO(hello_world)
+//!     MACRO(hello_world)
 //!
-//!         print_hello_world()
-//!     "#)
-//! }
+//!     print_hello_world()
+//! "#);
 //! ```
 
 mod cpp;
@@ -24,18 +22,24 @@ use proc_macro::TokenStream;
 /// # Example
 ///
 /// ```no_run
-/// fn main() {
-///     cpreprocess::cpreprocess!(r#"
-///         #define MACRO(NAME) fn print_ ## NAME () { println!("hello world"); }
+/// cpreprocess::cpreprocess!(r#"
+///     #define MACRO(NAME) fn print_ ## NAME () { println!("hello world"); }
 ///
-///         MACRO(hello_world)
+///     MACRO(hello_world)
 ///
-///         print_hello_world()
-///     "#)
-/// }
+///     print_hello_world()
+/// "#);
 /// ```
 pub fn cpreprocess(tokens: TokenStream) -> TokenStream {
+	#[cfg(not(feature = "nightly"))]
 	let tokens = syn::parse_macro_input!(tokens as syn::LitStr).value();
+
+	#[cfg(feature = "nightly")]
+	let tokens = match syn::parse::<syn::LitStr>(tokens.clone()) {
+		Ok(tokens) => tokens.value(),
+		Err(_) => proc_macro_faithful_display::faithful_display(&tokens).to_string()
+	};
+
 	match cpp::preprocess(tokens.as_bytes())
 		.map(|result| {
 			result.and_then(|code| {
